"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));

var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));

var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

var path = require('path');

var fs = require('fs');

var shell = require('shelljs');

var inquire = require('inquirer');

var git = require('simple-git');

var logger = require('kyt-utils/logger');

var generatePaths = require('kyt-utils/paths');

var starterKyts = require('../../config/starterKyts');

var yarnOrNpm = require('../../utils/yarnOrNpm');

var _require = require('./utils'),
    installUserDependencies = _require.installUserDependencies,
    createDir = _require.createDir,
    copyStarterKytFiles = _require.copyStarterKytFiles;

var _require2 = require('./packages'),
    fakePackageJson = _require2.fakePackageJson,
    updateUserPackageJSON = _require2.updateUserPackageJSON;

var _require3 = require('./questions'),
    ypmQ = _require3.ypmQ,
    dirNameQ = _require3.dirNameQ,
    getRepoUrl = _require3.getRepoUrl;

module.exports = function (options) {
  // which package manager to use
  var defaultManager = yarnOrNpm(); // --package-manager

  var ypm = options.packageManager || defaultManager; // --local-path

  var localPath;

  if (options.localPath) {
    localPath = path.resolve(options.localPath);
  } // local vars


  var paths = {};
  var tmpDir;
  var tmpStarter; // For passed starter-kyts the root of the starter-kyt is the root of the repo

  var repoURL = 'https://github.com/nytimes/kyt.git';
  logger.start("Let's set up your new kyt project...");
  logger.log('✨  Answer a few questions to get started  ✨ \n'); // Comment the following to see verbose shell ouput.

  shell.config.silent = false;

  var removeTmpStarter = function removeTmpStarter() {
    return shell.rm('-rf', tmpStarter);
  };

  var bailProcess = function bailProcess(error) {
    logger.error("Failed to setup: ".concat(repoURL));

    if (error) {
      logger.log(error);
    }

    removeTmpStarter();
    process.exit();
  }; // setup tasks for starter-kyts


  var starterKytSetup = function starterKytSetup(starterName) {
    var npmName;

    if (starterName) {
      npmName = starterKyts.supported[starterName].npmName;
      tmpDir = path.join(tmpDir, "/node_modules/".concat(npmName, "/starter-src"));
    }

    var kytName = starterName || localPath || repoURL;
    logger.task("Setting up the ".concat(starterName || 'specified', " starter-kyt")); // First, clean any old cloned repositories.

    removeTmpStarter();

    var afterCopy = function afterCopy(error) {
      if (error) {
        logger.error('There was a problem downloading the starter-kyt');
        logger.log(error);
        bailProcess();
        return false;
      }

      var starterKytConfig;

      try {
        // eslint-disable-next-line
        starterKytConfig = require("".concat(tmpDir, "/kyt.config.js"));
      } catch (e) {
        starterKytConfig = {};
      }

      var starterPackageJSON = JSON.parse(fs.readFileSync("".concat(tmpDir, "/package.json"), 'utf8'));

      var _updateUserPackageJSO = updateUserPackageJSON(starterPackageJSON, starterKytConfig, paths, options.kytVersion),
          oldUserPackageJSON = _updateUserPackageJSO.oldUserPackageJSON;

      installUserDependencies(paths, ypm, oldUserPackageJSON, bailProcess);
      copyStarterKytFiles(paths, starterPackageJSON, tmpDir);
      removeTmpStarter();
      logger.end("Done adding starter kyt: ".concat(kytName, "  \u2728"));
      return true;
    };

    if (localPath) {
      shell.exec("cp -R ".concat(localPath, " ").concat(tmpStarter));
      return afterCopy();
    }

    if (npmName) {
      shell.mkdir(tmpStarter);
      shell.cd(tmpStarter);
      var fakePkgPath = "".concat(tmpStarter, "/package.json");
      fs.writeFileSync(fakePkgPath, JSON.stringify(fakePackageJson, null, 2));
      var iCmd = ypm === 'yarn' ? 'yarn add' : 'npm install';
      var output = shell.exec("".concat(iCmd, " ").concat(npmName));

      if (output.code !== 0) {
        throw output.stderr;
      }

      shell.cd('..');
      return afterCopy();
    }

    if (repoURL) {
      var simpleGit = git();
      return simpleGit.clone(repoURL, tmpStarter).then(function () {
        afterCopy();
      });
    }

    return Promise.reject(new Error('No starter-kyt specified!'));
  }; // Runs through setup questions


  var setupPrompt = /*#__PURE__*/function () {
    var _ref = (0, _asyncToGenerator2["default"])( /*#__PURE__*/_regenerator["default"].mark(function _callee() {
      var ownRepo, questions;
      return _regenerator["default"].wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              ownRepo = 'I have my own url';
              questions = []; // Check to see if yarn is installed or user has specified flag

              if (defaultManager === 'yarn' && !options.packageManager) {
                questions.push(ypmQ);
              }

              if (!options.directory) {
                questions.push(dirNameQ);
              }

              if (!options.repository && !options.localPath) {
                questions.push({
                  type: 'list',
                  name: 'starterChoice',
                  message: 'Choose a starter-kyt:',
                  choices: [].concat((0, _toConsumableArray2["default"])(Object.keys(starterKyts.supported)), [ownRepo]),
                  "default": 0
                });
              }

              _context.next = 7;
              return inquire.prompt(questions).then(function (answer) {
                // 0-3 questions have been answered
                // if ypm question was asked and answered
                if (answer.ypm) {
                  ypm = answer.ypm;
                } // Create new directory if --directory was passed or question was answered


                // Create new directory if --directory was passed or question was answered
                if (options.directory || answer.dirName) {
                  createDir(options.directory || answer.dirName);
                } // set up path strings


                // set up path strings
                paths = generatePaths();
                tmpStarter = path.resolve(paths.userRootPath, '.kyt-tmp'); // For passed starter-kyts the root of the starter-kyt is the root of the repo

                // For passed starter-kyts the root of the starter-kyt is the root of the repo
                tmpDir = tmpStarter;

                if (answer.starterChoice === ownRepo || options.repository) {
                  // add repo question then move on to src prompt
                  return getRepoUrl(options.repository).then(function (url) {
                    repoURL = url;
                    return starterKytSetup();
                  })["catch"](function (e) {
                    logger.error(e);
                    process.exit(1);
                  });
                }

                if (starterKyts.supported[answer.starterChoice] || localPath) {
                  return starterKytSetup(answer.starterChoice);
                }

                return undefined;
              });

            case 7:
            case "end":
              return _context.stop();
          }
        }
      }, _callee);
    }));

    return function setupPrompt() {
      return _ref.apply(this, arguments);
    };
  }();

  try {
    setupPrompt();
  } catch (err) {
    bailProcess(err);
  }
};