"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.copyStarterKytFiles = exports.createDir = exports.installUserDependencies = void 0;

var fs = require('fs');

var path = require('path');

var shell = require('shelljs');

var logger = require('kyt-utils/logger'); // Cleans and reinstalls node modules.


var installUserDependencies = function installUserDependencies(paths, ypm, oldUserPackageJSON, bailProcess) {
  logger.info('Cleaning node modules and reinstalling. This may take a couple of minutes...'); // shell.rm('-rf', paths.userNodeModulesPath);

  var result = shell.exec("".concat(ypm, " install"));

  if (result.code !== 0) {
    fs.writeFileSync(paths.userPackageJSONPath, JSON.stringify(oldUserPackageJSON, null, 2));
    logger.error('An error occurred when trying to install node modules', result.stderr);
    logger.task('Restored the original package.json and bailing');
    logger.info('You may need to reinstall your modules');
    bailProcess();
  }

  logger.task('Installed new modules');
};

exports.installUserDependencies = installUserDependencies;

var createDir = function createDir(dirName) {
  if (!dirName) {
    return;
  }

  var checkAndBail = function checkAndBail(code) {
    if (code) {
      logger.error("Unable to create directory ".concat(dirName, ". Exiting..."));
      process.exit(1);
    }
  }; // Creates project directory if one is specified


  logger.task("Creating your new project at ".concat(dirName));
  var output = shell.mkdir(dirName);
  checkAndBail(output.code);
  output = shell.cd(dirName);
  checkAndBail(output.code);
};

exports.createDir = createDir;

var copyStarterKytFiles = function copyStarterKytFiles(paths, tempPackageJSON, tmpDir) {
  var kytStarterFiles = tempPackageJSON.kyt && tempPackageJSON.kyt.files || [];

  if (kytStarterFiles.length === 0) {
    return;
  }

  kytStarterFiles.forEach(function (file) {
    if (file === 'package.json') {
      return;
    }

    var tempFilePath = path.join(tmpDir, file);
    var filePath = path.join(paths.userRootPath, file); // we should back up any pre-existing files in the user dir.

    if (shell.test('-f', filePath) || shell.test('-d', filePath)) {
      var fileBackup = path.join(paths.userRootPath, "".concat(file, "-").concat(Date.now(), "-bak"));
      shell.mv(filePath, fileBackup);
      logger.info("Backed up current '".concat(file, "' to: ").concat(fileBackup));
    }

    shell.cp('-Rf', tempFilePath, paths.userRootPath);
    logger.task("Copied ".concat(file, " from Starter-kyt"));
  });
};

exports.copyStarterKytFiles = copyStarterKytFiles;