"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));

// Development webpack config for client code
var path = require('path');

var webpack = require('webpack');

var errorOverlayMiddleware = require('react-dev-utils/errorOverlayMiddleware');

var _require = require('kyt-runtime/webpack'),
    kytWebpackPlugins = _require.kytWebpackPlugins;

var _require2 = require('kyt-utils/paths')(),
    clientSrcPath = _require2.clientSrcPath,
    assetsBuildPath = _require2.assetsBuildPath,
    publicBuildPath = _require2.publicBuildPath;

var getPolyfill = require('./getPolyfill');

module.exports = function (options) {
  var main = [require.resolve('./webpackHotDevClient'), getPolyfill(options.type), "".concat(clientSrcPath, "/index.js")].filter(Boolean);
  return {
    mode: 'development',
    target: 'web',
    devtool: 'cheap-module-source-map',
    entry: {
      main: main
    },
    output: {
      path: assetsBuildPath,
      publicPath: options.publicPath,
      pathinfo: true,
      libraryTarget: 'var',
      filename: '[name].js',
      chunkFilename: '[name]-[chunkhash].js',
      devtoolModuleFilenameTemplate: function devtoolModuleFilenameTemplate(info) {
        return path.resolve(info.resourcePath).replace(/\\/g, '/');
      }
    },
    devServer: {
      disableHostCheck: true,
      clientLogLevel: 'none',
      compress: true,
      headers: {
        'Access-Control-Allow-Origin': '*'
      },
      historyApiFallback: {
        // Paths with dots should still use the history fallback.
        // See https://github.com/facebookincubator/create-react-app/issues/387.
        disableDotRule: true
      },
      publicPath: options.publicPath,
      // load hashed files from `build/public`
      contentBase: publicBuildPath,
      host: options.clientURL.hostname,
      hot: true,
      noInfo: true,
      overlay: false,
      port: options.clientURL.port,
      // By default files from `contentBase` will not trigger a page reload.
      quiet: true,
      // Reportedly, this avoids CPU overload on some systems.
      // https://github.com/facebookincubator/create-react-app/issues/293
      watchOptions: {
        ignored: /node_modules/
      },
      before: function before(app) {
        // This lets us open files from the runtime error overlay.
        app.use(errorOverlayMiddleware());
      }
    },
    plugins: [].concat((0, _toConsumableArray2["default"])(kytWebpackPlugins(options)), [new webpack.HotModuleReplacementPlugin()])
  };
};