"use strict";

// Development webpack config for server code
var webpack = require('webpack');

var nodeExternals = require('webpack-node-externals');

var _require = require('kyt-utils/paths')(),
    serverSrcPath = _require.serverSrcPath,
    serverBuildPath = _require.serverBuildPath,
    clientAssetsFile = _require.clientAssetsFile,
    loadableAssetsFile = _require.loadableAssetsFile;

var StartServerPlugin = require('./StartServerPlugin');

var getPolyfill = require('./getPolyfill');

var nodeArgs = ['-r', 'source-map-support/register', '--max_old_space_size=4096']; // Passthrough --inspect and --inspect-brk flags (with optional [host:port] value) to node

if (process.env.INSPECT_BRK) {
  nodeArgs.push(process.env.INSPECT_BRK);
} else if (process.env.INSPECT) {
  nodeArgs.push(process.env.INSPECT);
}

module.exports = function (options) {
  var externals;

  if (options.modulesDir && Array.isArray(options.modulesDir)) {
    externals = options.modulesDir.map(function (dir) {
      return nodeExternals({
        modulesDir: dir,
        allowlist: ['webpack/hot/poll?300']
      });
    });
  } else {
    externals = [nodeExternals({
      modulesDir: options.modulesDir,
      allowlist: ['webpack/hot/poll?300']
    })];
  }

  return {
    mode: 'development',
    watch: true,
    target: 'node',
    devtool: 'cheap-module-source-map',
    node: {
      __dirname: false,
      __filename: false
    },
    externals: externals,
    entry: {
      main: [require.resolve('./prettyNodeErrors'), 'webpack/hot/poll?300', getPolyfill(options.type), "".concat(serverSrcPath, "/index.js")].filter(Boolean)
    },
    output: {
      path: serverBuildPath,
      filename: '[name].js',
      chunkFilename: '[name]-[chunkhash].js',
      publicPath: options.publicPath,
      libraryTarget: 'commonjs2'
    },
    plugins: [// Prevent creating multiple chunks for the server
    new webpack.optimize.LimitChunkCountPlugin({
      maxChunks: 1
    }), new webpack.HotModuleReplacementPlugin(), new StartServerPlugin({
      name: 'main.js',
      nodeArgs: nodeArgs
    }), // Ignore to avoid infinite recompile bug
    new webpack.WatchIgnorePlugin([clientAssetsFile, loadableAssetsFile])]
  };
};