"use strict";

// Production webpack config for server code
var webpack = require('webpack');

var nodeExternals = require('webpack-node-externals');

var _require = require('kyt-utils/paths')(),
    serverSrcPath = _require.serverSrcPath,
    serverBuildPath = _require.serverBuildPath;

var getPolyfill = require('./getPolyfill');

module.exports = function (options) {
  var externals;

  if (options.modulesDir && Array.isArray(options.modulesDir)) {
    externals = options.modulesDir.map(function (dir) {
      return nodeExternals({
        modulesDir: dir
      });
    });
  } else {
    externals = [nodeExternals({
      modulesDir: options.modulesDir
    })];
  }

  return {
    mode: 'production',
    target: 'node',
    devtool: 'source-map',
    node: {
      __dirname: false,
      __filename: false
    },
    externals: externals,
    entry: {
      main: [getPolyfill(options.type), "".concat(serverSrcPath, "/index.js")].filter(Boolean)
    },
    output: {
      path: serverBuildPath,
      filename: '[name].js',
      chunkFilename: '[name]-[chunkhash].js',
      publicPath: options.publicPath,
      libraryTarget: 'commonjs2'
    },
    plugins: [new webpack.BannerPlugin({
      banner: 'require("source-map-support").install();',
      raw: true,
      entryOnly: true
    })]
  };
};